<div align="center">
  <img src=https://github.com/Quantum-Accelerators/quacc/blob/main/docs/images/quacc_logo_wide.png width="300"><br>
</div>

# quacc – The Quantum Accelerator 🦆

![tests](https://github.com/quantum-accelerators/quacc/actions/workflows/tests.yaml/badge.svg)
[![codecov](https://codecov.io/gh/Quantum-Accelerators/quacc/branch/main/graph/badge.svg?token=OJaOZAH30u)](https://codecov.io/gh/Quantum-Accelerators/quacc)
[![DeepSource](https://app.deepsource.com/gh/Quantum-Accelerators/quacc.svg/?label=active+issues&token=Y1NxOLIuFFEqWdjawIYnJNde)](https://app.deepsource.com/gh/Quantum-Accelerators/quacc/?ref=repository-badge)
![PyPI - Version](https://img.shields.io/pypi/v/quacc?color=blue)
![Python - Version](https://img.shields.io/pypi/pyversions/quacc)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7720998.svg)](https://doi.org/10.5281/zenodo.7720998)

Quacc is a flexible and extensible platform for high-throughput computational materials science and quantum chemistry maintained by the [Rosen Research Group](https://rosen.cbe.princeton.edu/) at Princeton University.

The three main goals of quacc are to:

1. Reduce the barrier for running complex, mixed-code workflows for molecules and materials across distributed compute environments.

2. Promote rapid workflow development and testing via modern [workflow management solutions](https://workflows.community/).

3. Enable a seamless interface between the [Atomic Simulation Environment](https://wiki.fysik.dtu.dk/ase/) and the software infrastructure powering the [Materials Project](https://materialsproject.org).

Quacc currently has [pre-made recipes](https://quantum-accelerators.github.io/quacc/user/recipes/recipes_list.html) for the following packages: DFTB+, Gaussian, GULP, NewtonNet, ORCA, Psi4, Q-Chem, tblite, and VASP. It's simple to add your favorite!

## Documentation

<p align="center">
  📖 <a href="https://quantum-accelerators.github.io/quacc/"><b><i>Learn More Here!</i></b></a> 📖
</p>

Includes the following sections:

- 🏎️ [Quick Start](https://quantum-accelerators.github.io/quacc/start/demo.html)
- 🔧 [Installation Guide](https://quantum-accelerators.github.io/quacc/install/install.html)
- 🧠 [User Guide](https://quantum-accelerators.github.io/quacc/user/recipes/recipes_intro.html)
- 🤝 [Developer Guide](https://quantum-accelerators.github.io/quacc/dev/contributing.html)

## Demonstration ✨

🚀 Demo from the Quick Start guide, using [Covalent](https://github.com/AgnostiqHQ/covalent) as one of the [several supported workflow managers](https://quantum-accelerators.github.io/quacc/user/basics/wflow_overview.html).

![](https://github.com/Quantum-Accelerators/quacc/blob/main/docs/images/start/start.gif)

## Citation

If you use quacc in your work, please cite it as follows:

- quacc – The Quantum Accelerator, https://doi.org/10.5281/zenodo.7720998.

## License ⚖️

Quacc is released under a [BSD 3-Clause license](https://github.com/quantum-accelerators/quacc/blob/main/LICENSE.md).
